/**
 * @file
 * Provides Zooming loader.
 */

(function ($, Drupal) {

  "use strict";

  /**
   * Toggle zooming classes.
   *
   * @param {HTMLElement} target
   *   The target HTML element.
   * @param {Bool} isOpen
   *   If it is zooming.
   */
  function toggleClasses(target, isOpen) {
    $('body')[isOpen ? 'addClass' : 'removeClass']('is-zooming');
    $(target).parents('.grid')[isOpen ? 'addClass' : 'removeClass']('is-zooming__zoomed');
  }

  /**
   * Zooming utility functions.
   *
   * @param {int} i
   *   The index of the current element.
   * @param {HTMLElement} elm
   *   The Zooming HTML element.
   */
  function doZooming(i, elm) {
    var options = {
      onImageLoading: function (target) {
        toggleClasses(target, true);
        $('body').addClass('is-zooming--loading');
      },
      onImageLoaded: function (target) {
        $('body').removeClass('is-zooming--loading');
      },
      onOpen: function (target) {
        toggleClasses(target, true);
        $('body').addClass('is-zooming--open');
      },
      onClose: function (target) {
        toggleClasses(target, false);
        $('body').addClass('is-zooming--open');
        $(target).removeAttr('style');
      }
    };

    new Zooming(options).listen('.media__zooming');
  }

  /**
   * Attaches zooming behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.zooming = {
    attach: function (context) {
      $("[data-zooming-trigger], .zooming", context).once("zooming", doZooming);
    }
  };

})(jQuery, Drupal);
